@@ -24,9 +24,11 @@ setClass("MIndex",
     )
 )
 
-### Combine the new parallel slots with those of the parent class. Make sure
-### to put the new parallel slots *first*.
-setMethod("parallelSlotNames", "MIndex",
+### Combine the new "vertical slots" with those of the parent class. Make
+### sure to put the new vertical slots **first**. See R/bindROWS.R file in
+### the S4Vectors package for what slots should or should not be considered
+### "vertical".
+setMethod("vertical_slot_names", "MIndex",
     function(x) c("width0", "NAMES", callNextMethod())
 )
 
@@ -124,9 +126,11 @@ setClass("ByPos_MIndex",
     )
 )
 
-### Combine the new parallel slots with those of the parent class. Make sure
-### to put the new parallel slots *first*.
-setMethod("parallelSlotNames", "ByPos_MIndex",
+### Combine the new "vertical slots" with those of the parent class. Make
+### sure to put the new vertical slots **first**. See R/bindROWS.R file in
+### the S4Vectors package for what slots should or should not be considered
+### "vertical".
+setMethod("vertical_slot_names", "ByPos_MIndex",
     function(x) c("dups0", "ends", callNextMethod())
 )
 
