@@ -17,9 +17,11 @@ setClass("PairwiseAlignments",
     )
 )
 
-### Combine the new parallel slots with those of the parent class. Make sure
-### to put the new parallel slots *first*.
-setMethod("parallelSlotNames", "PairwiseAlignments",
+### Combine the new "vertical slots" with those of the parent class. Make
+### sure to put the new vertical slots **first**. See R/bindROWS.R file in
+### the S4Vectors package for what slots should or should not be considered
+### "vertical".
+setMethod("vertical_slot_names", "PairwiseAlignments",
     function(x) c("pattern", "subject", "score", callNextMethod())
 )
 
@@ -438,8 +440,8 @@ setMethod("pid", "PairwiseAlignments",
     width <- getOption("width") - 9L - width
     pattern1 <- toSeqSnippet(alignedPattern(x1)[[1L]], width)
     subject1 <- toSeqSnippet(alignedSubject(x1)[[1L]], width)
-    cat("pattern:", p1start, " ", pattern1, "\n", sep="")
-    cat("subject:", s1start, " ", subject1, "\n", sep="")
+    cat("pattern:", p1start, " ", add_colors(pattern1), "\n", sep="")
+    cat("subject:", s1start, " ", add_colors(subject1), "\n", sep="")
     cat("score:", score(x1), "\n")
 }
 
